positions-class: Virtual Classes for Time-Related Objects
Description
The positions, positionsNumeric, and positionsCalendar classes
are virtual classes that represent positions for series objects.
The timeInterval class represents time intervals.Details
- The
positionsNumericclass is a class union ofnumericSequenceandnumeric, allowing representations of
numeric positions either by a sequence object or simply a vector. - The
positionsCalendaris aVIRTUALclass and is
extended bytimeDateandtimeSequence. - The
positionsclass is a class union ofpositionsNumericandpositionsCalendar. - The
timeIntervalclass is extended
bytimeSpanandtimeRelative.
See Also
timeDate class and timeSequence class.